/*********************************************************
** Recv program                                         **
**                                                      **
** Usage: recv <nr of frames>                           **
**                                                      **
** Output:                                              **
**     <frame nr>  <stamp>  <length>                    **
**                                                      **
** Copyright 1993 DNPAP group.                          **
** Author(s): Richard Kooijman R.Kooijman@et.tudelft.nl **
**            Dirk Wisse       D.M.Wisse@et.tudelft.nl  **
**                                                      **
*********************************************************/

#include <limits.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h> 
#include "type.h"
#include "nit.h"


typedef struct
{
    struct timeval     stamp;
    unsigned short     length;
} FRAME;



void main(int argc, char **argv)
{ 
    FRAME     *trace;
    NIT     *nit;
    ULONG     i, frames, bufsize, framelength, snaplength, drops;   
    TIMEVAL timeval, timeout, stamp;
    UINT     flags, options; 
    BYTE     *buf;

      if (argc < 2)
    {
        fprintf(stderr,"usage: %s <frames>\n", argv[0]);
        exit(1);
    }
    
    if (sscanf(argv[1],"%ld", &frames) != 1)
    {
        fprintf(stderr,"illegal value for <frames>: %s\n", argv[1]);
        exit(1);
    }
     
    NitInit(argc, argv);

    timeout.tv_sec     = LONG_MAX;
    timeout.tv_usec = 0;
    flags             = NI_PROMISC | NI_TIMESTAMP | NI_DROPS | NI_LEN;
    options         = 0;
    bufsize         = 64*1024L;
    snaplength        = 64;
    
    if ((nit = NitOpen("le0", bufsize, snaplength, timeout, flags, options)) == NULL)
    {
        fprintf(stderr, "open of le0 failed\n");
        exit(1);
    }
    
    trace = (FRAME *)malloc(frames * sizeof(FRAME));
    if (trace == NULL)
    {
        fprintf(stderr, "malloc of %d frames failed\n", frames);
        exit(1);
    }
             
    for (i=0; i<frames; i++)
    {   
        if ((buf = NitRead(nit, &snaplength, &framelength, &stamp, &drops)) == NULL)
        {
            fprintf(stderr, "read failed\n");
            exit(1);
        }

        trace[i].stamp.tv_sec  = stamp.tv_sec;
        trace[i].stamp.tv_usec = stamp.tv_usec;
        trace[i].length = framelength;
    }
    
    for (i=0; i<frames; i++)
    {               
        printf("%10lu %10lu.%06lu %5hu\n",
            i,
            trace[i].stamp.tv_sec,
            trace[i].stamp.tv_usec,
            trace[i].length);
    }
 
    free(trace);
}    

